==> projen-0.80.4-sources.jar: io/github/cdklabs/projen/javascript/TypescriptConfigOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-28T17:20:29.368Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypescriptConfigOptions")
@software.amazon.jsii.Jsii.Proxy(TypescriptConfigOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TypescriptConfigOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Compiler options to use.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions();

    /**
     * (experimental) Filters results from the "include" option.
     * <p>
     * Default: - node_modules is excluded by default
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getExclude() {
        return null;
    }

    /**
     * (experimental) Base <code>tsconfig.json</code> configuration(s) to inherit from.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.TypescriptConfigExtends getExtendsValue() {
        return null;
    }

    /**
     * Default: "tsconfig.json"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFileName() {
        return null;
    }

    /**
     * (experimental) Specifies a list of glob patterns that match TypeScript files to be included in compilation.
     * <p>
     * Default: - all .ts files recursively
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getInclude() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TypescriptConfigOptions> {
        io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions;
        java.util.List<java.lang.String> exclude;
        io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue;
        java.lang.String fileName;
        java.util.List<java.lang.String> include;

        /**
         * Sets the value of {@link TypescriptConfigOptions#getCompilerOptions}
         * @param compilerOptions Compiler options to use. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compilerOptions(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions) {
            this.compilerOptions = compilerOptions;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getExclude}
         * @param exclude Filters results from the "include" option.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(java.util.List<java.lang.String> exclude) {
            this.exclude = exclude;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getExtendsValue}
         * @param extendsValue Base <code>tsconfig.json</code> configuration(s) to inherit from.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder extendsValue(io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue) {
            this.extendsValue = extendsValue;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getFileName}
         * @param fileName the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(java.lang.String fileName) {
            this.fileName = fileName;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getInclude}
         * @param include Specifies a list of glob patterns that match TypeScript files to be included in compilation.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(java.util.List<java.lang.String> include) {
            this.include = include;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TypescriptConfigOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TypescriptConfigOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TypescriptConfigOptions {
        private final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions;
        private final java.util.List<java.lang.String> exclude;
        private final io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue;
        private final java.lang.String fileName;
        private final java.util.List<java.lang.String> include;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.compilerOptions = software.amazon.jsii.Kernel.get(this, "compilerOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions.class));
            this.exclude = software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.extendsValue = software.amazon.jsii.Kernel.get(this, "extends", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypescriptConfigExtends.class));
            this.fileName = software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.include = software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.compilerOptions = java.util.Objects.requireNonNull(builder.compilerOptions, "compilerOptions is required");
            this.exclude = builder.exclude;
            this.extendsValue = builder.extendsValue;
            this.fileName = builder.fileName;
            this.include = builder.include;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions() {
            return this.compilerOptions;
        }

        @Override
        public final java.util.List<java.lang.String> getExclude() {
            return this.exclude;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.TypescriptConfigExtends getExtendsValue() {
            return this.extendsValue;
        }

        @Override
        public final java.lang.String getFileName() {
            return this.fileName;
        }

        @Override
        public final java.util.List<java.lang.String> getInclude() {
            return this.include;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("compilerOptions", om.valueToTree(this.getCompilerOptions()));
            if (this.getExclude() != null) {
                data.set("exclude", om.valueToTree(this.getExclude()));
            }
            if (this.getExtendsValue() != null) {
                data.set("extends", om.valueToTree(this.getExtendsValue()));
            }
            if (this.getFileName() != null) {
                data.set("fileName", om.valueToTree(this.getFileName()));
            }
            if (this.getInclude() != null) {
                data.set("include", om.valueToTree(this.getInclude()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.TypescriptConfigOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TypescriptConfigOptions.Jsii$Proxy that = (TypescriptConfigOptions.Jsii$Proxy) o;

            if (!compilerOptions.equals(that.compilerOptions)) return false;
            if (this.exclude != null ? !this.exclude.equals(that.exclude) : that.exclude != null) return false;
            if (this.extendsValue != null ? !this.extendsValue.equals(that.extendsValue) : that.extendsValue != null) return false;
            if (this.fileName != null ? !this.fileName.equals(that.fileName) : that.fileName != null) return false;
            return this.include != null ? this.include.equals(that.include) : that.include == null;
        }

        @Override
        public final int hashCode() {
            int result = this.compilerOptions.hashCode();
            result = 31 * result + (this.exclude != null ? this.exclude.hashCode() : 0);
            result = 31 * result + (this.extendsValue != null ? this.extendsValue.hashCode() : 0);
            result = 31 * result + (this.fileName != null ? this.fileName.hashCode() : 0);
            result = 31 * result + (this.include != null ? this.include.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.80.14-sources.jar: io/github/cdklabs/projen/javascript/TypescriptConfigOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-03-27T17:08:55.598Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypescriptConfigOptions")
@software.amazon.jsii.Jsii.Proxy(TypescriptConfigOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface TypescriptConfigOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Compiler options to use.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions() {
        return null;
    }

    /**
     * (experimental) Filters results from the "include" option.
     * <p>
     * Default: - node_modules is excluded by default
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getExclude() {
        return null;
    }

    /**
     * (experimental) Base <code>tsconfig.json</code> configuration(s) to inherit from.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.javascript.TypescriptConfigExtends getExtendsValue() {
        return null;
    }

    /**
     * Default: "tsconfig.json"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getFileName() {
        return null;
    }

    /**
     * (experimental) Specifies a list of glob patterns that match TypeScript files to be included in compilation.
     * <p>
     * Default: - all .ts files recursively
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getInclude() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<TypescriptConfigOptions> {
        io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions;
        java.util.List<java.lang.String> exclude;
        io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue;
        java.lang.String fileName;
        java.util.List<java.lang.String> include;

        /**
         * Sets the value of {@link TypescriptConfigOptions#getCompilerOptions}
         * @param compilerOptions Compiler options to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compilerOptions(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions) {
            this.compilerOptions = compilerOptions;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getExclude}
         * @param exclude Filters results from the "include" option.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(java.util.List<java.lang.String> exclude) {
            this.exclude = exclude;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getExtendsValue}
         * @param extendsValue Base <code>tsconfig.json</code> configuration(s) to inherit from.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder extendsValue(io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue) {
            this.extendsValue = extendsValue;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getFileName}
         * @param fileName the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(java.lang.String fileName) {
            this.fileName = fileName;
            return this;
        }

        /**
         * Sets the value of {@link TypescriptConfigOptions#getInclude}
         * @param include Specifies a list of glob patterns that match TypeScript files to be included in compilation.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(java.util.List<java.lang.String> include) {
            this.include = include;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TypescriptConfigOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public TypescriptConfigOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TypescriptConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TypescriptConfigOptions {
        private final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions;
        private final java.util.List<java.lang.String> exclude;
        private final io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue;
        private final java.lang.String fileName;
        private final java.util.List<java.lang.String> include;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.compilerOptions = software.amazon.jsii.Kernel.get(this, "compilerOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions.class));
            this.exclude = software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.extendsValue = software.amazon.jsii.Kernel.get(this, "extends", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypescriptConfigExtends.class));
            this.fileName = software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.include = software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.compilerOptions = builder.compilerOptions;
            this.exclude = builder.exclude;
            this.extendsValue = builder.extendsValue;
            this.fileName = builder.fileName;
            this.include = builder.include;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions() {
            return this.compilerOptions;
        }

        @Override
        public final java.util.List<java.lang.String> getExclude() {
            return this.exclude;
        }

        @Override
        public final io.github.cdklabs.projen.javascript.TypescriptConfigExtends getExtendsValue() {
            return this.extendsValue;
        }

        @Override
        public final java.lang.String getFileName() {
            return this.fileName;
        }

        @Override
        public final java.util.List<java.lang.String> getInclude() {
            return this.include;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCompilerOptions() != null) {
                data.set("compilerOptions", om.valueToTree(this.getCompilerOptions()));
            }
            if (this.getExclude() != null) {
                data.set("exclude", om.valueToTree(this.getExclude()));
            }
            if (this.getExtendsValue() != null) {
                data.set("extends", om.valueToTree(this.getExtendsValue()));
            }
            if (this.getFileName() != null) {
                data.set("fileName", om.valueToTree(this.getFileName()));
            }
            if (this.getInclude() != null) {
                data.set("include", om.valueToTree(this.getInclude()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.TypescriptConfigOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TypescriptConfigOptions.Jsii$Proxy that = (TypescriptConfigOptions.Jsii$Proxy) o;

            if (this.compilerOptions != null ? !this.compilerOptions.equals(that.compilerOptions) : that.compilerOptions != null) return false;
            if (this.exclude != null ? !this.exclude.equals(that.exclude) : that.exclude != null) return false;
            if (this.extendsValue != null ? !this.extendsValue.equals(that.extendsValue) : that.extendsValue != null) return false;
            if (this.fileName != null ? !this.fileName.equals(that.fileName) : that.fileName != null) return false;
            return this.include != null ? this.include.equals(that.include) : that.include == null;
        }

        @Override
        public final int hashCode() {
            int result = this.compilerOptions != null ? this.compilerOptions.hashCode() : 0;
            result = 31 * result + (this.exclude != null ? this.exclude.hashCode() : 0);
            result = 31 * result + (this.extendsValue != null ? this.extendsValue.hashCode() : 0);
            result = 31 * result + (this.fileName != null ? this.fileName.hashCode() : 0);
            result = 31 * result + (this.include != null ? this.include.hashCode() : 0);
            return result;
        }
    }
}
